#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# Date          : 2025-08-28
# Author        : Lancelot PINCET
# GitHub        : https://github.com/LancelotPincet
# Library       : opticLP

"""
A library that calculates simple calculations for optical alignments.
"""



# %% Source code
sources = {

}



# %% Lazy imports
from corelp import getmodule
__getattr__, __all__ = getmodule(sources)